// $URL: http://subversion:8080/svn/gsc/trunk/drivers/LINUX/16AICS32/samples/id/perform.c $
// $Rev: 52040 $
// $Date: 2022-11-22 10:07:35 -0600 (Tue, 22 Nov 2022) $

// 16AICS32: Sample Application: source file

#include "main.h"



//*****************************************************************************
static int _input_modes(void)
{
	gsc_label("Input Modes");
	printf("Differential, Single Ended, Zero Test, +Vref Test\n");
	return(0);
}



//*****************************************************************************
static int _voltage_ranges(void)
{
	gsc_label("Voltage Ranges");
	printf("+-10V, +-5V, +-2.5V\n");
	return(0);
}



//*****************************************************************************
static int _clocking_sources(void)
{
	gsc_label("Clocking Sources");
	printf("Rate Generator(s), External, Software\n");
	return(0);
}



//*****************************************************************************
static int _sampling_modes(void)
{
	gsc_label("Sampling Modes");
	printf("Sequential, Single Shot\n");
	return(0);
}



//*****************************************************************************
static int _id_device_bcfgr(const args_t* args)
{
	gsc_reg_def_t	list[2]	= { { NULL }, { NULL } };
	gsc_reg_def_t*	ptr;

	int	errs	= 0;

	printf("\n");
	ptr	= (gsc_reg_def_t*) aics32_reg_get_def_id(AICS32_GSC_BCFGR);

	if (ptr)
	{
		list[0]	= ptr[0];
		errs	= gsc_reg_list(args->fd, list, 1, aics32_reg_read);
	}
	else
	{
		errs++;
		printf(	"FAIL <---  (%d. aics32_reg_get_def_id, AICS32_GSC_BCFGR)\n",
				__LINE__);
	}

	return(errs);
}



//*****************************************************************************
static int _register_map(const args_t* args)
{
	int	errs;

	printf("\n");
	errs	= aics32_reg_list(args->fd, args->detail);
	return(errs);
}



//*****************************************************************************
int perform_tests(const args_t* args)
{
	int	errs	= 0;
	int	i;

	gsc_label("Device Features");
	printf("\n");

	gsc_label_level_inc();

	errs	+= _input_modes();
	errs	+= _voltage_ranges();
	errs	+= _clocking_sources();
	errs	+= _sampling_modes();

	for (i = 0; i < AICS32_QUERY_COUNT; i++)
		aics32_query(args->fd, -1, 1, i, NULL);

	gsc_label_level_dec();

	errs	+= _id_device_bcfgr(args);
	errs	+= _register_map(args);
	printf("\n");

	return(errs);
}


