// $URL: http://subversion:8080/svn/gsc/trunk/drivers/LINUX/16AICS32/utils/util_config_ai.c $
// $Rev: 52039 $
// $Date: 2022-11-22 10:06:09 -0600 (Tue, 22 Nov 2022) $

// 16AICS32: Utilities: source file

#include "main.h"



/******************************************************************************
*
*	Function:	aics32_config_ai
*
*	Purpose:
*
*		Configure the Analog Input services.
*
*	Arguments:
*
*		fd		The handle to use to access the driver.
*
*		index	The index of the device to access. Ignore if < 0.
*
*		verbose	Work verbosely?
*
*		size	The desired scan size.
*
*		fsamp	The desired sample rate.
*
*	Returned:
*
*		>= 0	The number of errors encountered here.
*
******************************************************************************/

int	aics32_config_ai(int fd, int index, int verbose, s32 size, s32 fsamp)
{
	s32	enable_a;
	s32	enable_b;
	int	errs	= 0;
	s32	nrate_a;
	s32	nrate_b;
	s32	qty		= 32;
	s32	src;
	s32	src_b;

	if (verbose)
	{
		gsc_label_index("Input Configuration", index);
		gsc_label_level_inc();
		printf("\n");
	}

	errs	+= aics32_query					(fd, index, verbose, AICS32_QUERY_CHANNEL_QTY, &qty);

	errs	+= aics32_initialize			(fd, index, verbose);
	errs	+= aics32_rx_io_mode			(fd, index, verbose, GSC_IO_MODE_PIO,				NULL);
	errs	+= aics32_rx_io_timeout			(fd, index, verbose, AICS32_IO_TIMEOUT_DEFAULT,		NULL);
	errs	+= aics32_ai_buf_thr_lvl		(fd, index, verbose, 60000,							NULL);
	errs	+= aics32_ai_mode				(fd, index, verbose, AICS32_AI_MODE_DIFF,			NULL);
	errs	+= aics32_ai_range				(fd, index, verbose, AICS32_AI_RANGE_10V,			NULL);
	errs	+= aics32_scan_size				(fd, index, verbose, size,							NULL);
	errs	+= aics32_scan_single			(fd, index, verbose, 0,								NULL);
	errs	+= aics32_data_format			(fd, index, verbose, AICS32_DATA_FORMAT_OFF_BIN,	NULL);
	errs	+= aics32_excitation_mask_set	(fd, index, verbose, 0x00000000);
	errs	+= aics32_excitation_test		(fd, index, verbose, AICS32_EXCITATION_TEST_OFF,	NULL);
	errs	+= aics32_irq0_sel				(fd, index, verbose, AICS32_IRQ0_INIT_DONE,			NULL);
	errs	+= aics32_irq1_sel				(fd, index, verbose, AICS32_IRQ1_NONE,				NULL);
	errs	+= aics32_ext_sync				(fd, index, verbose, AICS32_EXT_SYNC_DISABLE,		NULL);
	errs	+= aics32_fsamp_ai_compute		(fd, index, verbose, fsamp, &src, &src_b, &nrate_a, &nrate_b, &enable_a, &enable_b, NULL);
	errs	+= aics32_ai_clk_src			(fd, index, verbose, src,							NULL);
	errs	+= aics32_rbg_clk_src			(fd, index, verbose, src_b,							NULL);
	errs	+= aics32_rag_nrate				(fd, index, verbose, nrate_a,						NULL);
	errs	+= aics32_rbg_nrate				(fd, index, verbose, nrate_b,						NULL);
	errs	+= aics32_rag_enable			(fd, index, verbose, enable_a,						NULL);
	errs	+= aics32_rbg_enable			(fd, index, verbose, enable_b,						NULL);
	errs	+= aics32_fsamp_ai_report_all	(fd, index, verbose,								NULL);
//	errs	+= aics32_auto_calibrate		(fd, index, verbose);	// Cable may need disconnecting for this.
	errs	+= aics32_ai_buf_clear			(fd, index, verbose);

	if (verbose)
		gsc_label_level_dec();

	return(errs);
}


