// $URL: http://subversion:8080/svn/gsc/trunk/drivers/LINUX/16AICS32/utils/util_ext_sync.c $
// $Rev: 44854 $
// $Date: 2019-05-10 15:32:59 -0500 (Fri, 10 May 2019) $

// 16AICS32: Utilities: source file

#include "main.h"



/******************************************************************************
*
*	Function:	aics32_ext_sync
*
*	Purpose:
*
*		Provide a visual wrapper for the AICS32_IOCTL_EXT_SYNC service.
*
*	Arguments:
*
*		fd		Use this handle to access the device.
*
*		index	The index of the device to access. Ignore if < 0.
*				This is for display purposes only.
*
*		verbose	Work verbosely?
*
*		set		This is the value to apply.
*
*		get		The results are reported here. This may be NULL.
*
*	Returned:
*
*		>= 0	The number of errors encounterred.
*
******************************************************************************/

int aics32_ext_sync(int fd, int index, int verbose, s32 set, s32* get)
{
	char		buf[128];
	int			errs;
	const char*	ptr;
	int			ret;

	if (verbose)
		gsc_label_index("External Sync", index);

	ret		= aics32_ioctl(fd, AICS32_IOCTL_EXT_SYNC, &set);
	errs	= ret ? 1 : 0;


	switch (set)
	{
		default:

			errs++;
			ptr	= buf;
			sprintf(buf, "Unrecognized option: 0x%lX", (long) set);
			break;

		case AICS32_EXT_SYNC_DISABLE:

			ptr	= "Disable";
			break;

		case AICS32_EXT_SYNC_ENABLE:

			ptr	= "Enable";
			break;
	}

	if (verbose)
		printf("%s  (%s)\n", errs ? "FAIL <---" : "PASS", ptr);

	if (get)
		get[0]	= set;

	return(errs);
}


